#
# This file is part of the Poke package
#
# (c) 2014 Julien Brochet <mewt@madalynn.eu>
#
# For the full copyright and license information, please view the LICENSE
# file that was distributed with this source code.
#

require 'poke/check'
require 'poke/version'

require 'poke/checks/blacklist/free_blacklist_check'
require 'poke/checks/blacklist/spamcop_blacklist_check'
require 'poke/checks/blacklist/spamhaus_blacklist_check'

require 'poke/checks/network/certificate_expiration_check'

require 'poke/outputers/outputer'
require 'poke/outputers/verbose_outputer'

module Poke
  class Poke
    # Constructor
    #
    def initialize(checks, outputer)
      @checks = checks
      @outputer = outputer
    end

    # Launch all checks in the same time
    #
    def run
      @outputer.on_start(@checks)

      @checks.each_with_index do |check, index|
        @outputer.on_check_before(check, index)
        returncode, message = check.run
        @outputer.on_check_after(check, {:returncode => returncode, :message => message})
      end

      @outputer.on_end
    end
  end
end