#
# This file is part of the Poke package
#
# (c) 2014 Julien Brochet <mewt@madalynn.eu>
#
# For the full copyright and license information, please view the LICENSE
# file that was distributed with this source code.
#

require 'nokogiri'
require 'open-uri'

module Poke
  module Checks
    module Blacklist
      class SpamhausBlacklistCheck < Poke::Check
        def initialize(ip)
          name = "Blacklist of #{ip} (Spamhaus)"
          @ip = ip
          super name
        end

        # Run the check
        def run
          html = URI.parse("http://www.spamhaus.org/query/ip/#{@ip}").read
          doc = Nokogiri::HTML(html)
          nodes = doc.search("//span[@class='body']//b/font")

          spamhaus_nodes = {
              0 => "SBL",
              1 => "PBL",
              2 => "XBL"
          }

          global_returncode = :ok
          global_message = ""

          spamhaus_nodes.each do |index, spamtype|
            returncode, message = test_node(nodes, index)
            global_returncode = :error if returncode == :error

            global_message += "[#{spamtype}] #{message} | "
          end

          # Find a better way to do this...
          global_message = global_message.chop.chop

          return global_returncode, global_message
        end

        private

        # Test a node
        #
        # @param [Array] HTML nodes
        # @param [Integer] Node index
        def test_node(nodes, index)
          message = nodes.at(index).inner_text

          return :ok, message if message =~ /not listed/
          return :error, message
        end
      end
    end
  end
end