#
# This file is part of the Poke package
#
# (c) 2014 Julien Brochet <mewt@madalynn.eu>
#
# For the full copyright and license information, please view the LICENSE
# file that was distributed with this source code.
#

require "colorize"

module Poke
  module Outputers
    class VerboseOutputer
      def on_start(checks)
        puts "POKE #{VERSION}".cyan
        puts "Automated network checks".cyan
        puts "#{checks.size} checks in the database".cyan
        puts ""

        @checks = 0
        @checks_ok = 0
        @checks_nok = 0
      end

      def on_check_before(check, index)
        puts "Check ##{index + 1}: #{check.name}".yellow
        @checks += 1
      end

      def on_check_after(check, options = {})
        if options[:returncode] == :ok
          puts "✔ ".green + options[:message].green
          @checks_ok += 1
        else
          puts "✘ ".red + options[:message].red
          @checks_nok += 1
        end

        puts ""
      end

      def on_end
        puts "Finish - Sum up".cyan
        puts "#{@checks} checks | " + "#{@checks_ok} ok".green + " | " + "#{@checks_nok} not ok".red
      end
    end
  end
end